summaryrefslogtreecommitdiff
path: root/gcc/flow.c
diff options
context:
space:
mode:
authorkazu <kazu@138bc75d-0d04-0410-961f-82ee72b054a4>2002-09-22 14:09:34 +0000
committerkazu <kazu@138bc75d-0d04-0410-961f-82ee72b054a4>2002-09-22 14:09:34 +0000
commit6ef828f9e997f2a593360aa6ce158d9f5ae739a0 (patch)
treed2db7ebbe3f404f7fa5e30b7ecf4ac4675f5b518 /gcc/flow.c
parent43e00fc9fcdb8cf219d4f9cf9ff1d45dbcbadeee (diff)
downloadgcc-6ef828f9e997f2a593360aa6ce158d9f5ae739a0.tar.gz
* dbxout.c: Follow spelling conventions.
* defaults.h: Likewise. * df.c: Likewise. * diagnostic.h: Likewise. * doloop.c: Likewise. * dwarf2out.c: Likewise. * dwarfout.c: Likewise. * emit-rtl.c: Likewise. * except.c: Likewise. * explow.c: Likewise. * expmed.c: Likewise. * expr.c: Likewise. * expr.h: Likewise. * flags.h: Likewise. * flow.c: Likewise. * fold-const.c: Likewise. * function.c: Likewise. * function.h: Likewise. * gcc.c: Likewise. * gcov-io.h: Likewise. * gcov.c: Likewise. * gcse.c: Likewise. * genattrtab.c: Likewise. * genconfig.c: Likewise. * genrecog.c: Likewise. * ggc-page.c: Likewise. * ggc.h: Likewise. * global.c: Likewise. * gthr-win32.h: Likewise. * integrate.c: Likewise. * jump.c: Likewise. * langhooks.c: Likewise. * langhooks.h: Likewise. * line-map.h: Likewise. * local-alloc.c: Likewise. * longlong.h: Likewise. * loop.c: Likewise. * loop.h: Likewise. git-svn-id: svn+ssh://gcc.gnu.org/svn/gcc/trunk@57406 138bc75d-0d04-0410-961f-82ee72b054a4
Diffstat (limited to 'gcc/flow.c')
-rw-r--r--gcc/flow.c8
1 files changed, 4 insertions, 4 deletions
diff --git a/gcc/flow.c b/gcc/flow.c
index 0c6d614b3b7..2905917cbcc 100644
--- a/gcc/flow.c
+++ b/gcc/flow.c
@@ -269,7 +269,7 @@ struct propagate_block_info
/* The length of mem_set_list. */
int mem_set_list_len;
/* Non-zero if the value of CC0 is live. */
int cc0_live;
/* Flags controling the set of information propagate_block collects. */
@@ -797,7 +797,7 @@ update_life_info_in_dirty_blocks (extent, prop_flags)
/* Free the variables allocated by find_basic_blocks.
- KEEP_HEAD_END_P is non-zero if basic_block_info is not to be freed. */
+ KEEP_HEAD_END_P is nonzero if basic_block_info is not to be freed. */
void
free_basic_block_vars (keep_head_end_p)
@@ -2042,7 +2042,7 @@ free_propagate_block_info (pbi)
case, the resulting set will be equal to the union of the two sets that
would otherwise be computed.
- Return non-zero if an INSN is deleted (i.e. by dead code removal). */
+ Return nonzero if an INSN is deleted (i.e. by dead code removal). */
int
propagate_block (bb, live, local_set, cond_local_set, flags)
@@ -2096,7 +2096,7 @@ propagate_block (bb, live, local_set, cond_local_set, flags)
(SET expressions whose destinations are registers dead after the insn).
NEEDED is the regset that says which regs are alive after the insn.
- Unless CALL_OK is non-zero, an insn is needed if it contains a CALL.
+ Unless CALL_OK is nonzero, an insn is needed if it contains a CALL.
If X is the entire body of an insn, NOTES contains the reg notes
pertaining to the insn. */
@@ -269,7 +269,7 @@ struct propagate_block_info
/* The length of mem_set_list. */
int mem_set_list_len;
- /* Non-zero if the value of CC0 is live. */
+ /* Nonzero if the value of CC0 is live. */
int cc0_live;
/* Flags controling the set of information propagate_block collects. */